@@ -12,10 +12,10 @@ $|++;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(menu);
 
-our $VERSION = '0.97';
+our $VERSION = '0.98';
 
 # Set up the terminal handling
-$ENV{TERM} = 'ascii' if !defined $ENV{TERM} or $ENV{TERM} == '';
+$ENV{TERM} = 'linux' if !defined $ENV{TERM} or $ENV{TERM} == '';
 my $ti = POSIX::Termios->new();
 $ti->getattr;
 my $t = Term::Cap->Tgetent({ TERM => undef, OSPEED => $ti->getospeed||38400 });
